FunctionCall class
Function call details
Constructors
-
FunctionCall({required String name, required Map<
String, dynamic> arguments, FunctionCallStatus status = FunctionCallStatus.pending}) - Create a new function call
-
FunctionCall.fromJson(Map<
String, dynamic> json) -
Create a function call from a JSON map
factory
Properties
-
arguments
→ Map<
String, dynamic> -
Function arguments
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Function name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → FunctionCallStatus
-
Function call status
final
Methods
-
copyWith(
{String? name, Map< String, dynamic> ? arguments, FunctionCallStatus? status}) → FunctionCall - Create a copy of this function call with modified properties
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert function call to a JSON map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited