AudioStatusEvent class
音频状态变更事件
Constructors
- AudioStatusEvent({required bool isPlaying, required bool isCapturing})
- 构造函数
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCapturing → bool
-
是否正在采集
final
- isPlaying → bool
-
是否正在播放
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited